==> byteplus_rtc-3.44.1.tar.gz: lib/api/bytertc_spatial_audio_api.dart <==
// Copyright 2022 BytePlus Pte. Ltd.
// SPDX-License-Identifier: MIT

import 'bytertc_audio_defines.dart';

/// Spatial audio instance
abstract class RTCSpatialAudio {
  /// Enables/disables spatial audio function.
  ///
  /// This method only enables the spatial audio function, you have to call [RTCSpatialAudio.updatePosition] to set your own position coordinates before the user can really enjoy the spatial audio effect.<br>
  /// See [Spatial Audio](https://docs.byteplus.com/byteplus-rtc/docs/93903) for more spatial audio-related APIs and call order.
  Future<void> enableSpatialAudio(bool enable);

  /// Updates the coordinate of the local user's position in the rectangular coordinate system in the current room.
  ///
  /// [pos]: 3D coordinate values, the default value is [0, 0, 0].
  ///
  /// Notes:
  /// + Call [RTCSpatialAudio.enableSpatialAudio] to enable spatial audio function first before calling this API.
  /// + See [Spatial Audio](https://docs.byteplus.com/byteplus-rtc/docs/93903) for more spatial audio-related APIs and call order.
  Future<int?> updatePosition(Position pos);

  /// After the local user joins the room, call this API to update the orientation of the local user in the 3D coordinates for the spatial audio.
  ///
  /// Notes:
  /// + See [Spatial Audio](https://docs.byteplus.com/byteplus-rtc/docs/93903) for more spatial audio-related APIs and call order.
  /// + Ignore the remote user's orientation by calling [RTCSpatialAudio.disableRemoteOrientation].
  Future<int?> updateSelfOrientation(HumanOrientation orientation);

  /// Calling this API to neglect the orientation of the remote users. All remote users will be considered as facing the local user.<br>
  /// Calling [RTCSpatialAudio.updateSelfOrientation] then will notify none of the remote users.<br>
  /// However, the local user can feel the change in audio effect brought about by their own orientation change when receiving audio.
  ///
  /// Notes:
  /// + You can call this API anytime before or after the local user joins the room.
  /// + Once the orientation is disabled by calling this API, you cannot enable it again within the lifetime of the `RTCSpatialAudio` instance.
  Future<void> disableRemoteOrientation();
}

==> byteplus_rtc-3.51.1.tar.gz: lib/api/bytertc_spatial_audio_api.dart <==
// Copyright 2022 BytePlus Pte. Ltd.
// SPDX-License-Identifier: MIT

import 'bytertc_audio_defines.dart';

/// Spatial audio instance
abstract class RTCSpatialAudio {
  /// Enables/disables spatial audio function.
  ///
  /// This method only enables the spatial audio function, you have to call [RTCSpatialAudio.updatePosition] to set your own position coordinates before the user can really enjoy the spatial audio effect.<br>
  /// See [Spatial Audio](https://docs.byteplus.com/byteplus-rtc/docs/93903) for more spatial audio-related APIs and call order.
  Future<void> enableSpatialAudio(bool enable);

  /// Updates the coordinate of the local user's position in the rectangular coordinate system in the current room.
  ///
  /// [pos]: 3D coordinate values, the default value is `[0, 0, 0]`.
  ///
  /// Notes:
  /// + Call [RTCSpatialAudio.enableSpatialAudio] to enable spatial audio function first before calling this API.
  /// + See [Spatial Audio](https://docs.byteplus.com/byteplus-rtc/docs/93903) for more spatial audio-related APIs and call order.
  Future<int?> updatePosition(Position pos);

  /// After the local user joins the room, call this API to update the orientation of the local user in the 3D coordinates for the spatial audio.
  ///
  /// Notes:
  /// + See [Spatial Audio](https://docs.byteplus.com/byteplus-rtc/docs/93903) for more spatial audio-related APIs and call order.
  /// + Ignore the remote user's orientation by calling [RTCSpatialAudio.disableRemoteOrientation].
  Future<int?> updateSelfOrientation(HumanOrientation orientation);

  /// Calling this API to neglect the orientation of the remote users. All remote users will be considered as facing the local user.<br>
  /// Calling [RTCSpatialAudio.updateSelfOrientation] then will notify none of the remote users.<br>
  /// However, the local user can feel the change in audio effect brought about by their own orientation change when receiving audio.
  ///
  /// Notes:
  /// + You can call this API anytime before or after the local user joins the room.
  /// + Once the orientation is disabled by calling this API, you cannot enable it again within the lifetime of the `RTCSpatialAudio` instance.
  Future<void> disableRemoteOrientation();

  /// Updates the local user's position as a listener in the RTC room.<br>
  /// By calling this API, you can set the position of the local user as a listener different from the position as a sound source.
  ///
  /// [pos]: 3D coordinate values.<br>
  /// If the API is not called, the position as a listener is the same as that set by calling [RTCSpatialAudio.updatePosition].
  ///
  /// Return value:
  /// + 0: Success.
  /// + !0: Failure.
  ///
  /// Before calling this API, you should call [RTCSpatialAudio.enableSpatialAudio] first to enable the spatial audio function.
  Future<int?> updateListenerPosition(Position pos);

  /// Updates the local user's orientation as a listener in the RTC room.<br>
  /// By calling this API, you can set the orientation of the local user as a listener different from the orientation as a sound source.
  ///
  /// [orientation]: Self orientation information.<br>
  ///  If the API is not called, the orientation as a listener is the same as that set by calling [RTCSpatialAudio.updateSelfOrientation].
  ///
  /// Return value:
  /// + 0: Success.
  /// + !0: Failure.
  Future<int?> updateListenerOrientation(HumanOrientation orientation);
}
